#!/bin/bash

source /opt/velostrata/velostrata-functions

VELOS_DIR="/opt/velostrata/alias-ips"
UTIL_SCRIPTS_DIR="/etc/velostrata/alias-ips"
WICKED_SVC="/etc/wicked"
UBUNTU_NETPLAN="/etc/netplan"

DHCLIENT_SCRIPT="/etc/dhcp/dhclient.d/aliasip.sh"
if is_ubuntu_family ; then
	DHCLIENT_SCRIPT="/etc/dhcp/dhclient-exit-hooks.d/zz-aliasip"
elif is_suse ; then
   DHCLIENT_SCRIPT="/etc/sysconfig/network/if-up.d/zz-aliasip"
fi


# backward compatiblity mode from Velostrata 3.0
# remove leftovers from previos EC2-specific implementations
function cleanup_old_leftovers()
{
	rm -f /etc/dhcp/dhclient.d/ec2dhcp.sh
	rm -f /etc/dhcp/dhclient-exit-hooks.d/ec2dhcp
	rm -f /etc/sysconfig/network/if-up.d/ec2dhcp
	rm -f /etc/velostrata/actions/bypass/setup-ec2dhcp
}


CFG=$1
velos_log_syslog "setup-alias-ip, mode=${CFG}"

cleanup_old_leftovers

if [ "${CFG}" == "velos" ] ; then
	IBFT_HWADDR=`cat /sys/firmware/ibft/ethernet0/mac`
	if [ ! -z "${IBFT_HWADDR}" ] ; then
		INTERFACE=`get_nic_by_hwaddr ${IBFT_HWADDR}`
		. $VELOS_DIR/alias-ip-functions
		rewrite_rules
		rewrite_aliases
	fi
elif [ "${CFG}" == "detach" ] ; then
 	mkdir -p $UTIL_SCRIPTS_DIR
	cp -f $VELOS_DIR/alias-ip-utils ${UTIL_SCRIPTS_DIR}/
	cp -f $VELOS_DIR/alias-ip-functions ${UTIL_SCRIPTS_DIR}/
	cp -f $VELOS_DIR/aliasip.sh ${UTIL_SCRIPTS_DIR}/
	cp -f $VELOS_DIR/aliasip.sh $DHCLIENT_SCRIPT
	if [ -d ${WICKED_SVC} ] ; then
		install_wicked_script $VELOS_DIR/wicked-aliasip.sh
	fi
	if [ -d ${UBUNTU_NETPLAN} ] ; then
		install_systemd_service $VELOS_DIR/velostrata-aliasip.service multi-user.target
	fi
	touch /etc/velostrata/actions/bypass/setup-alias-ips
	touch /etc/velostrata/actions/apply-net-changes
elif [ "${CFG}" == "origin" ] ; then
	rm -f $DHCLIENT_SCRIPT
	rm -rf $UTIL_SCRIPTS_DIR
	rm -f /etc/velostrata/actions/bypass/setup-alias-ips
else
	velos_log_syslog "Unknown mode for setup-alias-ip, supported: origin / velos / detached)"
fi

