#!/bin/bash

source /opt/velostrata/velostrata-functions

kernel_ver=`uname -r`

# check and warn about BTRFS mount issues (see HA-3199 or https://github.com/systemd/systemd/issues/927)
btrfs_mnt=`cat /etc/fstab | grep btrfs | grep subvol | wc -l`
if [[ ${btrfs_mnt} -gt 0 && "${kernel_ver}" < "4.2" ]]; then
	velos_log "WARNING: Found BTRFS mounts in /etc/fstab which are known to have issues in this kernel version (${kernel_ver})"
	velos_log "For more details and workaround, please refer to: https://github.com/systemd/systemd/issues/927"
fi

# check for GRUB graphics
for ff in ${DEFAULT_GRUB_CONFIG_FILES[*]}; do
	if is_real_file ${ff} && find_active_str $ff "splashimage=" "gfxmenu" "vga="; then
		backup_file=${ff}.velos_bckp
		velos_log "GFX menu or splash image found in ${ff}, saving backup copy to ${backup_file}"
		cp -f ${ff} ${backup_file}
		replace_entry ${ff} "splashimage=" "#splashimage="
		replace_entry ${ff} "gfxmenu" "#gfxmenu"
		replace_entry ${ff} "vga=" "vga-disabled="
	fi
done

# add console log-in for suse 11 (see HA-6385)
if is_suse ; then
    suse_version="$(get_suse_version)"
    suse_required_version=11
    N=$(grep -n ttyS0 /etc/inittab | grep -Eo '^[^:]+')

    if [[ $suse_version -eq $suse_required_version ]]; then
            cp -f /etc/inittab /etc/inittab.velos_bckp
            sed -i ''$N's/^.//' /etc/inittab
    fi
fi

exit 0
